waitForUserInput property
bool
get
waitForUserInput
Whether to pause and wait for user input after processing.
Implementation
bool get waitForUserInput;
Whether to pause and wait for user input after processing.
bool get waitForUserInput;