enqueue method
Adds new sentences to the queue to be processed.
Implementation
void enqueue(List<BaseNarrativeModel> newSentences) {
for (final sentence in newSentences) {
_queue.addLast(sentence);
}
}
Adds new sentences to the queue to be processed.
void enqueue(List<BaseNarrativeModel> newSentences) {
for (final sentence in newSentences) {
_queue.addLast(sentence);
}
}