ProcessingStatus enum

ProcessingStatus - Enum representing engine state

Used to indicate the current state of the narrative engine. This allows reactive updates to UI and logic via listeners.

States:

  • idle: Engine is idle and not processing
  • processing: Actively processing sentences
  • paused: Temporarily paused mid-processing
  • cancelled: Cancelled before finishing
  • completed: Finished all sentences
Inheritance
Available extensions

Values

idle → const ProcessingStatus
processing → const ProcessingStatus
paused → const ProcessingStatus
cancelled → const ProcessingStatus
completed → const ProcessingStatus

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ProcessingStatus>
A constant List of the values in this enum, in order of their declaration.