onAsk property
Callback to show a question prompt and await a response.
Implementation
final Future<void> Function(BaseNarrativeModel sentence)? onAsk;
Callback to show a question prompt and await a response.
final Future<void> Function(BaseNarrativeModel sentence)? onAsk;