onUnhandled property
Called when the sentence instruction does not match any known type.
Implementation
final Future<void> Function(BaseNarrativeModel sentence)? onUnhandled;
Called when the sentence instruction does not match any known type.
final Future<void> Function(BaseNarrativeModel sentence)? onUnhandled;