onWrite property
Callback to write the sentence to the chat UI.
Implementation
final Future<void> Function(BaseNarrativeModel sentence)? onWrite;
Callback to write the sentence to the chat UI.
final Future<void> Function(BaseNarrativeModel sentence)? onWrite;