reset method
void
reset()
Manually clears the last recorded sentence.
Useful after a game reset or phase change where the next sentence might intentionally be repeated.
Implementation
void reset() {
_last = null;
}
Manually clears the last recorded sentence.
Useful after a game reset or phase change where the next sentence might intentionally be repeated.
void reset() {
_last = null;
}