FiftyNarrativeEnginePlatform class abstract

Platform interface for FiftyNarrativeEngine.

Platform-specific implementations should extend this class and implement the required methods. The default implementation uses method channels.

Inheritance
  • Object
  • PlatformInterface
  • FiftyNarrativeEnginePlatform
Implementers

Constructors

FiftyNarrativeEnginePlatform()
Constructs a FiftyNarrativeEnginePlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
Returns the platform version string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FiftyNarrativeEnginePlatform
The default instance of FiftyNarrativeEnginePlatform to use.
getter/setter pair