FiftyNarrativeEngineWeb class
A web implementation of the FiftyNarrativeEnginePlatform.
- Inheritance
-
- Object
- PlatformInterface
- FiftyNarrativeEnginePlatform
- FiftyNarrativeEngineWeb
Constructors
- FiftyNarrativeEngineWeb()
- Constructs a FiftyNarrativeEngineWeb.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
Returns a String containing the version of the platform.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
Registrar registrar) → void - Registers this class as the default instance of FiftyNarrativeEnginePlatform.